#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_RpiImager_main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_CommonStrings_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_Style_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_ConfirmUnfilterDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_ConfirmSystemDriveDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_KeychainPermissionDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_UpdateAvailableDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_PasswordlessSudoWarningDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_RepositoryDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_AppOptionsDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_DebugOptionsDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_dialogs_ConfirmOtpProgramDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_LanguageSelectionStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_BaseDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImButtonRed_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImCheckBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImComboBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_FocusableText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_FocusableHeading_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImFileDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImSaveFileDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImRadioButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImOptionPill_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImOptionButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImTextField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImPasswordField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_ImToggleTab_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_MarqueeText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_SelectionListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_qmlcomponents_OSSelectionListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_WizardStepBase_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_WizardContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_DeviceSelectionStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_OSSelectionStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_StorageSelectionStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_HostnameCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_IfAndFeaturesCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_LocaleCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_UserCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_WifiCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_RemoteAccessStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_SecureBootCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_PiConnectCustomizationStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_WritingStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_DoneStep_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_components_WizardSectionContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_components_WizardFormLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_components_WizardDescriptionText_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_RpiImager_wizard_components_SshKeyManager_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/main.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/CommonStrings.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_CommonStrings_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/Style.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_Style_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/ConfirmUnfilterDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_ConfirmUnfilterDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/ConfirmSystemDriveDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_ConfirmSystemDriveDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/KeychainPermissionDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_KeychainPermissionDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/UpdateAvailableDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_UpdateAvailableDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/PasswordlessSudoWarningDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_PasswordlessSudoWarningDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/RepositoryDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_RepositoryDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/AppOptionsDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_AppOptionsDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/DebugOptionsDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_DebugOptionsDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/dialogs/ConfirmOtpProgramDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_dialogs_ConfirmOtpProgramDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/LanguageSelectionStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_LanguageSelectionStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/BaseDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_BaseDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImButton.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImButtonRed.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImButtonRed_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImCheckBox.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImCheckBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImComboBox.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImComboBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/FocusableText.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_FocusableText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/FocusableHeading.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_FocusableHeading_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImFileDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImFileDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImSaveFileDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImSaveFileDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImRadioButton.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImRadioButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImOptionPill.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImOptionPill_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImOptionButton.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImOptionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImTextField.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImTextField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImPasswordField.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImPasswordField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/ImToggleTab.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_ImToggleTab_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/MarqueeText.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_MarqueeText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/SelectionListView.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_SelectionListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/qmlcomponents/OSSelectionListView.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_qmlcomponents_OSSelectionListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/WizardStepBase.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_WizardStepBase_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/WizardContainer.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_WizardContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/DeviceSelectionStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_DeviceSelectionStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/OSSelectionStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_OSSelectionStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/StorageSelectionStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_StorageSelectionStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/HostnameCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_HostnameCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/IfAndFeaturesCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_IfAndFeaturesCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/LocaleCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_LocaleCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/UserCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_UserCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/WifiCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_WifiCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/RemoteAccessStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_RemoteAccessStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/SecureBootCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_SecureBootCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/PiConnectCustomizationStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_PiConnectCustomizationStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/WritingStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_WritingStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/DoneStep.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_DoneStep_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/components/WizardSectionContainer.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_components_WizardSectionContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/components/WizardFormLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_components_WizardFormLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/components/WizardDescriptionText.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_components_WizardDescriptionText_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/RpiImager/wizard/components/SshKeyManager.qml"), &QmlCacheGeneratedCode::_qt_qml_RpiImager_wizard_components_SshKeyManager_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_rpi_imager)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_rpi_imager))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_rpi_imager)() {
    return 1;
}
